@@ -6,7 +6,7 @@
 */
 /* libburn wrappers for libisoburn 
 
-   Copyright 2007 - 2010  Thomas Schmitt, <scdbackup@gmx.net> 
+   Copyright 2007 - 2011  Thomas Schmitt, <scdbackup@gmx.net> 
    Provided under GPL version 2 or later.
 */
 
@@ -1723,6 +1723,7 @@ int isoburn_set_msc1(struct burn_drive *d, int adr_mode, char *adr_value,
  static int max_mode_names= 4;
  regex_t re;
  regmatch_t match[1];
+ enum burn_disc_status s;
 
  ret= isoburn_find_emulator(&o, d, 0);
  if(ret<0)
@@ -1783,6 +1784,14 @@ not_found:;
 
  } else if(adr_mode==3) {
    o->fabricated_msc1= adr_num;
+   s= isoburn_disc_get_status(d);
+   if(o->fabricated_msc1 > 0 && s != BURN_DISC_FULL
+      && s != BURN_DISC_APPENDABLE) {
+     isoburn_msgs_submit(o, 0x00060000,
+                         "Non-zero load offset given with blank input media",
+                         0, "FAILURE", 0);
+     ret= 0; goto ex;
+   }
    if((flag & 1) && o->fabricated_msc1 >= 16) {
      /* adr_num is possibly 16 blocks too high */
      ret= isoburn_read_iso_head(d, o->fabricated_msc1, &size,volid, 1|(1<<14));
