@@ -158,6 +158,8 @@ create_blank_image:;
        isoburn_report_iso_error(ret, "Cannot create image", 0, "FATAL", 0);
        return ret;
      }
+     iso_image_set_ignore_aclea(*image,
+                         (!!(read_opts->noacl)) | ((!!read_opts->noea) << 1) );
    } else {
      /* Blank new image for the drive */
      iso_image_unref(o->image);
@@ -166,13 +168,13 @@ create_blank_image:;
        isoburn_report_iso_error(ret, "Cannot create image", 0, "FATAL", 0);
        return ret;
      }
-     if (image) {
+     if (image != NULL) {
        *image = o->image;
        iso_image_ref(*image); /*protects object from premature free*/
      }
-   }
-   iso_image_set_ignore_aclea(*image,
+     iso_image_set_ignore_aclea(o->image,
                          (!!(read_opts->noacl)) | ((!!read_opts->noea) << 1) );
+   }
    return 1;
  }
  
@@ -226,8 +228,13 @@ displacement_rollover:;
  iso_read_opts_set_start_block(ropts, ms_block);
  iso_read_opts_set_no_rockridge(ropts, read_opts->norock);
  iso_read_opts_set_no_aaip(ropts, read_opts->noaaip);
- iso_read_opts_set_no_md5(ropts, read_opts->nomd5);
-
+ if(read_opts->nomd5 == 2)
+   int_num= 2;
+ else if(read_opts->nomd5 == 1)
+   int_num= 1;
+ else
+   int_num= 0;
+ iso_read_opts_set_no_md5(ropts, int_num);
  iso_read_opts_set_new_inos(ropts, read_opts->noino);
 
  iso_read_opts_set_no_joliet(ropts, read_opts->nojoliet);
