@@ -224,7 +224,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libisofs_req_major  1
 #define isoburn_libisofs_req_minor  0
-#define isoburn_libisofs_req_micro  2 
+#define isoburn_libisofs_req_micro  4 
 
 /** The minimum version of libburn to be used with this version of libisoburn
     at compile time.
@@ -232,7 +232,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libburn_req_major  1
 #define isoburn_libburn_req_minor  0
-#define isoburn_libburn_req_micro  2
+#define isoburn_libburn_req_micro  4
 
 /** The minimum compile time requirements of libisoburn towards libjte are
     the same as of a suitable libisofs towards libjte.
@@ -287,7 +287,7 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
 */
 #define isoburn_header_version_major  1
 #define isoburn_header_version_minor  0
-#define isoburn_header_version_micro  2
+#define isoburn_header_version_micro  4
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -770,6 +770,11 @@ int isoburn_ropt_destroy(struct isoburn_read_opts **o, int flag);
                bit9= nomd5
                      @since 0.4.2
                      Do not load the eventual MD5 checksum array.
+                     Do not check eventual session_md5 tags.
+              bit10= nomd5tag
+                     @since 1.0.4
+                     Do not check eventual session_md5 tags although bit9
+                     is not set.
     @return    1 success, <=0 failure
 */
 #define isoburn_ropt_norock         1
@@ -782,6 +787,7 @@ int isoburn_ropt_destroy(struct isoburn_read_opts **o, int flag);
 #define isoburn_ropt_noea         128
 #define isoburn_ropt_noino        256
 #define isoburn_ropt_nomd5        512
+#define isoburn_ropt_nomd5tag    1024
 
 int isoburn_ropt_set_extensions(struct isoburn_read_opts *o, int ext);
 int isoburn_ropt_get_extensions(struct isoburn_read_opts *o, int *ext);
@@ -984,7 +990,8 @@ int isoburn_igopt_get_level(struct isoburn_imgen_opts *o, int *level);
                  can encode ACL and XFS-style Extended Attributes.
            bit6= session_md5
                  @since 0.4.2
-                 Produce and write a MD5 checksum of the whole session stream.
+                 Produce and write MD5 checksum tags of superblock, directory
+                 tree, and the whole session stream.
            bit7= file_md5
                  @since 0.4.2
                  Produce and write MD5 checksums for each single IsoFile.
@@ -1336,6 +1343,13 @@ int isoburn_igopt_get_scdbackup_tag(struct isoburn_imgen_opts *o,
                              numbers 2 to 8.
                              This will overwrite the first 512 bytes of
                              the submitted data.
+                    bit8-9= Only with System area type 0 = MBR
+                          @since 1.0.4
+                          Cylinder alignment mode eventually pads the image
+                          to make it end at a cylinder boundary.
+                          0 = auto (align if bit1)
+                          1 = always align to cylinder boundary
+                          2 = never align to cylinder boundary
 
     @return 1 success, 0 no data to get, <0 failure
 */
