@@ -368,11 +368,10 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
    ext|= isoburn_ropt_noea; 
  if(xorriso->ino_behavior & 1)
    ext|= isoburn_ropt_noino;
-
-#ifdef isoburn_ropt_nomd5
  if(!(xorriso->do_md5 & 1))
    ext|= isoburn_ropt_nomd5;
-#endif
+ if(xorriso->do_md5 & 32)
+   ext|= isoburn_ropt_nomd5tag;
 
  isoburn_ropt_set_extensions(ropts, ext);
 
@@ -422,8 +421,11 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, int flag)
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, sev, 0);
    if(read_ret == ISO_SB_TREE_CORRUPTED && (xorriso->do_md5 & 1)) {
      Xorriso_msgs_submit(xorriso, 0,
-           "You might get a questionable ISO image tree by option -md5 'off'.",
-            0, "HINT", 0);
+"This might be false MD5 alarm if an add-on session was written by growisofs.",
+        0, "HINT", 0);
+     Xorriso_msgs_submit(xorriso, 0,
+      "In this case you get an ISO image tree by option -md5 'load_check_off'",
+        0, "HINT", 0);
    } else if(xorriso->img_read_error_mode!=0) {
      Xorriso_msgs_submit(xorriso, 0, "You might get a partial or altered ISO image tree by option -error_behavior 'image_loading' 'best_effort' if -abort_on is set to be tolerant enough.",
                          0, "HINT", 0);
