@@ -62,6 +62,7 @@ int Xorriso_cdrskin_help(struct XorrisO *xorriso, int flag)
 "\tstream_recording=on|number\ttry to get full speed on DVD-RAM, BD",
 "\tdvd_obs=default|32k|64k\t\tbytes per DVD/BD write operation",
 "\tstdio_sync=on|off|number\twhether to fsync output to \"stdio:\"",
+"\t--no_rc\t\tDo not execute xorriso startup files",
 "\t-help\t\tprint this text to stderr and exit emulation",
 "Actually this is the integrated ISO RockRidge filesystem manipulator xorriso",
 "lending its libburn capabilities to a very limited cdrecord emulation. Only",
@@ -259,6 +260,8 @@ no_volunteer:;
      do_multi= 1;
    } else if(strcmp(argv[i], "-nopad")==0) {
      xorriso->padding= 0;
+   } else if(strcmp(argv[i], "--no_rc")==0) {
+     /* already performed in Xorriso_prescan_args */;
    } else if(strcmp(argv[i], "-pad")==0) {
      xorriso->padding= 15*2048;
    } else if(strncmp(argv[i], "-padsize=", 9)==0 ||
@@ -535,6 +538,7 @@ int Xorriso_genisofs_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "--protective-msdos-label", "--boot-catalog-hide", "--no-emul-toc",
     "--emul-toc", "-disallow_dir_id_ext", "--old-empty",
     "--old-root-no-md5", "--old-root-devno", "--old-root-no-ino",
+    "--no_rc",
     ""
  };
  static char arg1_options[][41]= {
@@ -565,7 +569,7 @@ int Xorriso_genisofs_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "-checksum_algorithm_iso", "-checksum_algorithm_template",
     "--stdio_sync", "--quoted_path_list", "--efi-boot", "--embedded-boot",
     "-isohybrid-mbr", "-e", "-partition_offset", "-partition_hd_cyl",
-    "-partition_sec_hd", "-untranslated_name_len",
+    "-partition_sec_hd", "-partition_cyl_align", "-untranslated_name_len",
     ""
  };
  static char arg2_options[][41]= {
@@ -674,7 +678,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 {
  static char helptext[][160]= {
 "Usage: xorriso -as mkisofs [options] file...",
-"Note: This is not mkisofs. See xorriso -help, xorriso -version, man xorriso",
+"Note: This is not mkisofs. See xorriso -help, xorriso -version, man xorrisofs",
 "Options:",
 "  -f, -follow-links           Follow symbolic links",
 "  -graft-points               Allow to use graft points for filenames",
@@ -761,6 +765,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -partition_offset LBA       Make image mountable by first partition, too",
 "  -partition_sec_hd NUMBER    Define number of sectors per head",
 "  -partition_hd_cyl NUMBER    Define number of heads per cylinder",
+"  -partition_cyl_align MODE   Control cylinder alignment: off, on, auto",
 "  -mips-boot FILE             Set mips boot image name (relative to image root)",
 "  -mipsel-boot FILE           Set mipsel boot image name (relative to image root)",
 "  -B FILES, -sparc-boot FILES Set sparc boot image names",
@@ -785,6 +790,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  --old-root-no-md5           Do not record and use MD5 with -old-root",
 "  --old-root-no-ino           Do not use disk inode numbers with -old-root",
 "  --old-root-devno            Use disk device numbers with -old-root",
+"  --no_rc                     Do not execute startup files",
 "  -v, -verbose                Verbose",
 "  -version                    Print the current version",
 "@End_of_helptexT@"
@@ -893,7 +899,7 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
  int do_print_size= 0, fd, idx, iso_level= 1, emul_boot= 2;
  int option_b= 0, was_failure= 0, fret, lower_r= 0, zero= 0;
  int dir_mode= -1, file_mode= -1, count, partition_number, allow_dir_id_ext= 1;
- int root_seen= 0;
+ int root_seen= 0, do_md5_mem;
  mode_t mode_and, mode_or;
  int with_boot_image= 0, with_cat_path= 0, with_emul_toc= 0;
  int old_root_md5= 1, old_root_dev= 0, old_root_ino= 1;
@@ -902,7 +908,7 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
  char sfe[5*SfileadrL], adr[SfileadrL+8], ra_text[80], pathspec[2*SfileadrL];
  char *ept, *add_pt, eff_path[SfileadrL], indev[SfileadrL+8], msc[80], *cpt;
  char old_root[SfileadrL];
- char *boot_path, partno_text[8], *iso_rr_pt, *disk_pt;
+ char *boot_path, partno_text[8], *iso_rr_pt, *disk_pt, *rpt, *wpt;
  char *rm_merge_args[3];
 
  /* >>> This should not be static. Why is it ? */
@@ -1182,7 +1188,12 @@ illegal_c:;
      Xorriso_option_hardlinks(xorriso, "without_update", 0);
  }
  if(indev[0]) {
+   do_md5_mem= xorriso->do_md5;
+   if(xorriso->do_md5 & 1) /* MD5 loading is enabled */
+     xorriso->do_md5|= 32; /* Do not check tags of superblock,tree,session
+                              because growisofs preserves the first sb tag.*/
    ret= Xorriso_option_dev(xorriso, indev, 1);
+   xorriso->do_md5= do_md5_mem;
    if(ret<=0)
      goto ex;
  }
@@ -1359,6 +1370,7 @@ not_enough_args:;
              strcmp(argv[i], "-partition_offset") == 0 ||
              strcmp(argv[i], "-partition_hd_cyl") == 0 ||
              strcmp(argv[i], "-partition_sec_hd") == 0 ||
+             strcmp(argv[i], "-partition_cyl_align") == 0 ||
              strcmp(argv[i], "-isohybrid-mbr")==0) {
      if(i+1>=argc)
        goto not_enough_args;
@@ -1544,6 +1556,9 @@ not_enough_args:;
    } else if(strcmp(argv[i], "-disallow_dir_id_ext")==0) {
      /* was already handled in first argument scan */;
 
+   } else if(strcmp(argv[i], "--no_rc")==0) {
+     /* was already handled in Xorriso_prescan_args */;
+
    } else if(argv[i][0]=='-' && argv[i][1]!=0) {
      ret= Xorriso_genisofs_count_args(xorriso, argc - i, argv + i, &count, 1);
      if(ret > 0) {
@@ -1577,24 +1592,37 @@ is_pathspec_2:;
            pathspec[0]= 0;
        }
        strcat(pathspec, eff_path);
-       add_pt= pathspec;
      } else
-       add_pt= argv[i];
+       Sfile_str(pathspec, argv[i], 0);
+     add_pt= pathspec;
 
      if(old_root[0]) {
        /* Split pathspec */
-       ret= Fileliste__target_source_limit(pathspec, '=', &ept, 0);
+       ret= Fileliste__target_source_limit(add_pt, '=', &ept, 0);
        if(ret > 0) {
          *ept= 0;
-         iso_rr_pt= pathspec;
+         iso_rr_pt= add_pt;
          disk_pt= ept + 1;
        } else {
          iso_rr_pt= "/";
-         disk_pt= pathspec;
+         disk_pt= add_pt;
        }
+
+       /* Unescape iso_rr_pt */
+       strcpy(eff_path, iso_rr_pt);
+       iso_rr_pt= eff_path;
+       for(wpt= rpt= iso_rr_pt; *rpt != 0; rpt++) {
+         if(*rpt == '\\') {
+           if(*(rpt + 1) == '\\')
+             rpt++;
+           else if(*(rpt + 1) == '=')
+       continue;
+         }
+         *(wpt++) = *rpt;
+       }
+       *wpt= 0;
+
        if(root_seen) {
-         strcpy(eff_path, iso_rr_pt);
-         iso_rr_pt= eff_path;
          ret= Sfile_prepend_path(xorriso->wdi, iso_rr_pt, 0);
          if(ret<=0) {
            Xorriso_msgs_submit(xorriso, 0, "Effective path gets much too long",
@@ -1609,7 +1637,7 @@ is_pathspec_2:;
        xorriso->allow_graft_points= 1;
        zero= 0;
        ret= Xorriso_option_add(xorriso, 1, &add_pt, &zero,
-                               (was_path << 1) | (root_seen << 2));
+                               (was_path << 1) | (root_seen << 2) | 8);
        xorriso->allow_graft_points= mem_graft_points;
      }
      if(ret<=0)
@@ -1798,7 +1826,8 @@ problem_handler_2:;
      xorriso->boot_image_cat_hidden|= 3;
    } else if(strcmp(argv[i], "-partition_offset") == 0 ||
              strcmp(argv[i], "-partition_sec_hd") == 0 ||
-             strcmp(argv[i], "-partition_dh_cyl") == 0) {
+             strcmp(argv[i], "-partition_hd_cyl") == 0 ||
+             strcmp(argv[i], "-partition_cyl_align") == 0) {
      if(i+1>=argc)
        goto not_enough_args;
      i++;
@@ -1850,6 +1879,9 @@ problem_handler_boot:;
      was_failure= 1;
  }
 
+ if(xorriso->no_emul_toc & 1)
+   xorriso->do_padding_by_libisofs= 1;
+
  if(do_print_size) {
    ret= Xorriso_option_print_size(xorriso, 1);
    goto ex;
