@@ -377,7 +377,11 @@ int Findjob_new(struct FindjoB **o, char *start_path, int flag)
  if(m->start_path==NULL)
    goto failed;
  m->found_path= NULL;
+ m->estim_upper_size= 0;
+ m->estim_lower_size= 0;
  m->subjob= NULL;
+ m->errmsg[0]= 0;
+ m->errn= 0;
 
  ret= Exprnode_new(&(m->test_tree), m, NULL, "-find", (m->use_shortcuts)<<1);
  if(ret<=0)
