@@ -459,8 +459,8 @@ int Xorriso_boot_item_status(struct XorrisO *xorriso, char *cat_path,
  bit0= do only report non-default settings
  bit1= do only report to fp
 */
-int Xorriso_boot_status_mips(struct XorrisO *xorriso, IsoImage *image,
-                             char *filter, FILE *fp, int flag)
+int Xorriso_boot_status_non_mbr(struct XorrisO *xorriso, IsoImage *image,
+                                char *filter, FILE *fp, int flag)
 {
  int i, num_boots, sa_type;
  char *paths[15], *line;
@@ -468,6 +468,15 @@ int Xorriso_boot_status_mips(struct XorrisO *xorriso, IsoImage *image,
  line= xorriso->result_line;
 
  sa_type= (xorriso->system_area_options & 0xfc) >> 2;
+ if(sa_type == 3) {
+   sprintf(line, "-boot_image any sparc_label=");
+   Text_shellsafe(xorriso->ascii_disc_label, line, 1);
+   strcat(line, "\n");
+   Xorriso_status_result(xorriso, filter, fp, flag & 2);
+   return(0);
+ }
+ if(sa_type != 1 && sa_type != 2)
+   return(0);
  num_boots= iso_image_get_mips_boot_files(image, paths, 0);
  Xorriso_process_msg_queues(xorriso, 0);
  if(num_boots <= 0)
@@ -493,8 +502,8 @@ int Xorriso_append_part_status(struct XorrisO *xorriso, IsoImage *image,
 {
  int i;
 
- for(i= 0; i < 4; i++) {
-   if(xorriso->appended_partitions[i][0] == 0)
+ for(i= 0; i < Xorriso_max_appended_partitionS; i++) {
+   if(xorriso->appended_partitions[i] == NULL)
  continue;
    sprintf(xorriso->result_line, "-append_partition %d 0x%2.2x ",
            i + 1, (unsigned int) xorriso->appended_part_types[i]);
@@ -537,7 +546,7 @@ int Xorriso_boot_image_status(struct XorrisO *xorriso, char *filter, FILE *fp,
  if(image == NULL) 
    goto no_image;
  
- ret= Xorriso_boot_status_mips(xorriso, image, filter, fp, flag & 3);
+ ret= Xorriso_boot_status_non_mbr(xorriso, image, filter, fp, flag & 3);
  if(ret < 0) /* == 0 is normal */
    {ret= 0; goto ex;}
 
@@ -724,10 +733,15 @@ no_boot:;
  if(ret != 1)
    goto no_boot;
 
- ret= Xorriso_path_from_lba(xorriso, NULL, xorriso->loaded_boot_bin_lba,
-                             path, 1);
- if(ret > 0)
-   bin_path_valid= 1;
+ ret= iso_image_get_all_boot_imgs(image, &num_boots, &boots, &bootnodes, 0);
+ Xorriso_process_msg_queues(xorriso,0);
+ if(ret != 1) {
+   num_boots= 0;
+ } else {
+   ret= Xorriso_path_from_node(xorriso, (IsoNode *) bootnodes[0], path, 0);
+   if(ret > 0)
+     bin_path_valid= 1;
+ }
  sprintf(respt, "Boot record  : El Torito");
  if(bin_path_valid)
    ret= Xorriso_is_isohybrid(xorriso, bootimg_node, 0);
@@ -786,9 +800,7 @@ no_boot:;
  strcat(respt, "\n");
  Xorriso_toc_line(xorriso, flag & 8);
 
- ret= iso_image_get_all_boot_imgs(image, &num_boots, &boots, &bootnodes, 0);
- Xorriso_process_msg_queues(xorriso,0);
- if(ret == 1 && num_boots > 1) {
+ if(num_boots > 1) {
    for(i= 1; i < num_boots; i++) {
      ret= Xorriso_path_from_node(xorriso, (IsoNode *) bootnodes[i], path, 0);
      if(ret > 0)
@@ -842,6 +854,8 @@ int Xorriso_get_volume(struct XorrisO *xorriso, IsoImage **volume,
 
 int Xorriso_change_is_pending(struct XorrisO *xorriso, int flag)
 {
+ if(flag & 1)
+   return(xorriso->volset_change_pending == 1);
  return(!!xorriso->volset_change_pending);
 }
 
@@ -855,7 +869,9 @@ int Xorriso_set_change_pending(struct XorrisO *xorriso, int flag)
  ret= Xorriso_get_volume(xorriso, &image, 1);
  if(ret <= 0)
    return ret;
- xorriso->volset_change_pending= 1;
+ /* Do not override mark of -as mkisofs -print-size */
+ if(xorriso->volset_change_pending != 2)
+    xorriso->volset_change_pending= 1;
  if(!(flag & 1))
    xorriso->hln_change_pending= 1;
  return(1);
@@ -872,7 +888,7 @@ int Xorriso_mount(struct XorrisO *xorriso, char *dev, int adr_mode,
                   char *adr_value, char *cmd, int flag)
 {
  int ret, lba, track, session, params_flag= 0, is_safe= 0, is_extra_drive= 0;
- int give_up= 0, mount_chardev= 0, status;
+ int give_up= 0, mount_chardev= 0, status, aquire_flag= 0;
  char volid[33], *devadr, mount_command[SfileadrL], adr_data[163], *adr_pt;
  char *dev_path, libburn_adr[BURN_DRIVE_ADR_LEN + SfileadrL];
  char sfe[5 * SfileadrL], *dpt, *sysname= "";
@@ -941,7 +957,10 @@ int Xorriso_mount(struct XorrisO *xorriso, char *dev, int adr_mode,
    if(ret == 0 && strncmp(dev, "stdio:", 6) != 0)
      sprintf(libburn_adr, "stdio:%s", dev);
    burn_preset_device_open(xorriso->drives_exclusive, 0, 0);
-   ret= isoburn_drive_aquire(&dinfo, libburn_adr, 1);
+   aquire_flag= 1;
+   if((xorriso->toc_emulation_flag & 2) && adr_mode == 3)
+     aquire_flag|= 16;
+   ret= isoburn_drive_aquire(&dinfo, libburn_adr, aquire_flag);
    burn_preset_device_open(1, 0, 0);
    Xorriso_process_msg_queues(xorriso,0);
    if(ret <= 0)
@@ -961,7 +980,7 @@ int Xorriso_mount(struct XorrisO *xorriso, char *dev, int adr_mode,
  Xorriso_process_msg_queues(xorriso,0);
  if(ret <= 0)
    goto ex;
- if(session <= 0 || track <= 0 || ret == 2) {
+ if(((session <= 0 || track <= 0) && !(aquire_flag & 16)) || ret == 2) {
    Xorriso_msgs_submit(xorriso, 0,
                 "-mount : Given address does not point to an ISO 9660 session",
                 0, "FAILURE", 0);
@@ -1080,15 +1099,16 @@ int Xorriso_coordinate_system_area(struct XorrisO *xorriso, int sa_type,
                                    int options, char *cmd, int flag)
 {
  int old_type, old_options;
- static char *type_names[3] = {
-      "MBR", "MIPS Big Endian Volume Header", "MIPS Little Endian Boot Block"};
+ static char *type_names[4] = {
+      "MBR", "MIPS Big Endian Volume Header", "MIPS Little Endian Boot Block",
+      "SUN Disk Label"};
 
  old_type= (xorriso->system_area_options & 0xfc) >> 2;
  old_options= xorriso->system_area_options & ~0xfc;
  if((old_type != 0 || old_options != 0) &&
     (old_type != sa_type || (old_options != 0 && old_options != options))) {
    sprintf(xorriso->info_text, "%s : First sector already occupied by %s",
-           cmd, old_type < 2 ? type_names[old_type] : "other boot facility");
+           cmd, old_type < 4 ? type_names[old_type] : "other boot facility");
    if(old_type == 0 && old_options == 2)
      strcat(xorriso->info_text, " for ISOLINUX isohybrid");
    if(old_type == 0 && old_options == 1)
@@ -1106,7 +1126,9 @@ hint_revoke:;
    sprintf(xorriso->info_text, "Revokable by -boot_image any discard");
  else if(old_type == 1 || old_type == 2)
    sprintf(xorriso->info_text, "Revokable by -boot_image any mips_discard");
- if(old_type < 2)
+ else if(old_type == 3)
+   sprintf(xorriso->info_text, "Revokable by -boot_image any sparc_discard");
+ if(old_type < 4)
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "HINT", 0);
  return(0);
 }
