@@ -95,6 +95,7 @@ int Xorriso_option_acl(struct XorrisO *xorriso, char *mode, int flag)
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
                bit2= prepend ISO working directory in any case
+               bit3= unescape \\
 */
 int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
                        int *idx, int flag)
@@ -128,9 +129,12 @@ int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
      else
        rpt= wpt= source;
      for(; *rpt!=0; rpt++) {
-       if(*rpt=='\\')
+       if(*rpt=='\\') {
          if(*(rpt+1)=='=')
      continue;
+         if((flag & 8) && *(rpt + 1) == '\\')
+           rpt++;
+       }
        *(wpt++)= *rpt;
      }
      *wpt= 0;
@@ -932,6 +936,23 @@ treatment_patch:;
    }
    xorriso->partition_secs_per_head= u;
 
+ } else if(strncmp(treatpt, "partition_cyl_align=", 20)==0) {
+   if(strcmp(treatpt + 20, "auto") == 0)
+     xorriso->system_area_options= (xorriso->system_area_options & ~0x300);
+   else if(strcmp(treatpt + 20, "on") == 0)
+     xorriso->system_area_options=
+                               (xorriso->system_area_options & ~0x300) | 0x100;
+   else if(strcmp(treatpt + 20, "off") == 0)
+     xorriso->system_area_options=
+                               (xorriso->system_area_options & ~0x300) | 0x200;
+   else {
+     sprintf(xorriso->info_text,
+             "-boot_image %s partition_cyl_align: unknown mode : %s",
+             formpt, treatpt + 20);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+     return(0);
+   }
+
  } else if(strncmp(treatpt, "platform_id=", 12)==0) {
    if(strncmp(treatpt + 12, "0x", 2) == 0)
      sscanf(treatpt + 14, "%x", &u);
