@@ -399,6 +399,8 @@ int Xorriso_option_errfile_log(struct XorrisO *xorriso,
    sprintf(xorriso->info_text, "-errfile_log: Unknown mode %s",
            Text_shellsafe(mode, sfe, 0));
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   if(fp != NULL)
+     fclose(fp);
    return(0);
  }
  
@@ -1688,7 +1690,7 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "                 Give up any unejected drive afterwards.",
 "  -close \"on\"|\"off\"",
 "                 If \"on\" then mark the written media as not appendable.",
-"  -padding number[\"k\"|\"m\"]",
+"  -padding number[\"k\"|\"m\"]|\"included\"|\"appended\"",
 "                 Append extra bytes to image stream. (Default is 300k)",
 "  -dummy \"on\"|\"off\"",
 "                 If \"on\" simulate burning. Refuse if media cannot simulate.",
