@@ -641,6 +641,10 @@ int Xorriso_option_md5(struct XorrisO *xorriso, char *mode, int flag)
      xorriso->do_md5|= 8;
    else if(l == 19 && strncmp(cpt, "stability_check_off", l) == 0)
      xorriso->do_md5&= ~8;
+   else if(l == 13 && strncmp(cpt, "load_check_on", l) == 0)
+     xorriso->do_md5&= ~32;
+   else if(l == 14 && strncmp(cpt, "load_check_off", l) == 0)
+     xorriso->do_md5|= 32;
    else {
      sprintf(xorriso->info_text, "-md5: unknown mode ");
      Text_shellsafe(cpt, xorriso->info_text, 1);
