@@ -1576,7 +1576,9 @@ int Xorriso_prescan_args(struct XorrisO *xorriso, int argc, char **argv,
      ret= Xorriso_option_no_rc(xorriso, 0);
      if(ret<=0)
        goto ex;
-
+   } else if(xorriso->argument_emulation >= 1 &&
+             xorriso->argument_emulation <= 2) {
+     {ret= 1; goto ex;}
    } else if((strcmp(cmd,"dev")==0 || strcmp(cmd,"outdev")==0 ||
                                       strcmp(cmd,"indev")==0) &&
              (strcmp(arg1,"stdio:/dev/fd/1")==0 || strcmp(arg1,"-")==0) &&
