@@ -106,7 +106,7 @@ get_single:;
    l= strlen(cpt);
    if(l >= linesize - base_length - 1) {
      strncpy(linept, cpt, linesize - 1);
-     line[sizeof(line)-1]= 0;
+     line[linesize - 1]= 0;
      sprintf(xorriso->info_text,"Input line too long !");
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
      goto new_empty;
@@ -1295,6 +1295,13 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso,filter,fp,flag&2);
 
+ ret= (xorriso->system_area_options & 0x300) >> 8;
+ is_default= (ret == 0);
+ sprintf(line,"-boot_image any partition_cyl_align=%s\n",
+         ret == 0 ? "auto" : ret == 1 ? "on" : "off");
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso,filter,fp,flag&2);
+
  if((xorriso->system_area_disk_path[0] || !part_table_implicit) &&
     (xorriso->partition_offset == 0 || (xorriso->system_area_options & 2))) {
    is_default= ((xorriso->system_area_options & 3) == 0);
@@ -1616,6 +1623,11 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
  sprintf(line,"-padding %dk\n", xorriso->padding/1024);
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso,filter,fp,flag&2);
+ is_default= (xorriso->do_padding_by_libisofs == 0);
+ sprintf(line,"-padding %s\n",
+         xorriso->do_padding_by_libisofs ? "included" : "appended");
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso,filter,fp,flag&2);
 
  is_default= (strcmp(xorriso->report_about_text,"UPDATE")==0);
  sprintf(line,"-report_about %s\n",xorriso->report_about_text);
@@ -1690,6 +1702,13 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso, filter, fp, flag & 2);
 
+ is_default= (xorriso->displacement == 0);
+ sprintf(line, "-displacement %s%lu\n",
+               xorriso->displacement_sign < 0 ? "-" : "",
+               (unsigned long) xorriso->displacement);
+ if(!(is_default && no_defaults))
+   Xorriso_status_result(xorriso, filter, fp, flag & 2);
+
  adr_mode= xorriso->image_start_mode & 0xffff;
  if(adr_mode>=0 && adr_mode<=max_load_mode) {
    is_default= (adr_mode==0);
@@ -1784,14 +1803,16 @@ int Xorriso_status(struct XorrisO *xorriso, char *filter, FILE *fp, int flag)
  is_default= ((xorriso->do_md5 & 31) == 0);
  sprintf(line, "-md5 ");
  if(xorriso->do_md5 & 1) {
-   if((xorriso->do_md5 & (8)) == (8)) {
-     strcat(line, "all\n");
+   if((xorriso->do_md5 & 8) == 8) {
+     strcat(line, "all");
    } else {
      strcat(line, "on");
      if(xorriso->do_md5 & 8)
        strcat(line, ":stability_check_on");
-     strcat(line, "\n");
    }
+   if(xorriso->do_md5 & 32) 
+     strcat(line, ":load_check_off");
+   strcat(line, "\n");
  } else
    strcat(line, "off\n");
  if(!(is_default && no_defaults))
