@@ -150,6 +150,7 @@ struct XorrisO { /* the global context of xorriso */
                  bit2= write MD5 for each data file
                  bit3= make file content stability check by double reading
                  bit4= use recorded MD5 as proxy of ISO file
+                 bit5= with bit0: do not check tags of superblock,tree,session
                */
 
  int no_emul_toc; /* bit0= On overwriteables: 
@@ -295,10 +296,13 @@ struct XorrisO { /* the global context of xorriso */
  int speed;     /* in libburn units : 1000 bytes/second , 0 = Max, -1 = Min */
  int fs;        /* fifo size in 2048 byte chunks : at most 1 GB */
  int padding;   /* number of bytes to add after ISO 9660 image */
+ int do_padding_by_libisofs; /* 0= by libburn , 1= by libisofs */
 
- int alignment; /* if > 0 : image size alignment in 2048 byt blocks */
-                /* <<< not sure whether to keep this after libisofs will have
-                       learned to pad up MBR images to full MB */
+ int alignment; /* if > 0 : output size alignment in 2048 byte blocks.
+                            This is always done by libburn, i.e. attached
+                            outside the image. Eventual inner alignment of
+                            the image end happens first.
+                */
 
  int do_stream_recording; /* 0=no, 1=yes, 2=for data, not for dir
                              >=16 means yes with number as start LBA  */
@@ -338,6 +342,12 @@ struct XorrisO { /* the global context of xorriso */
                                                   else: unspecified type 
                                                1= MIPS Big Endian Volume Header
                                                2= MIPS Little Endian Boot Block
+                                               3= SUN Disk Label for SUN SPARC
+                                         bit8-9= Only with System area type 0
+                                               Cylinder alignment mode
+                                               0 = auto (align if bit1)
+                                               1 = always align
+                                               2 = never align
                                        */
  int patch_system_area;               /* Bits as of system_area_options.
                                          to be applied to the loaded system
